/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver.ipfilter;

import org.apache.mina.core.session.IoSession;

/**
 * The interface for filtering sessions based on various session attributes.
 *
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 *
 */

public interface SessionFilter {

    /**
     * Tells whether or not the given session is accepted by this filter.
     *
     * @param session
     *            the session to check
     * @return <code>true</code>, if the given session is accepted by this
     *         filter; <code>false</code>, otherwise.
     */
    boolean accept(IoSession session);

}
